import ApiEndpoints from './api-endpoints';
import { IObfuscatedPrecomputedConfigurationResponse } from './configuration-wire/configuration-wire-types';
import { BanditParameters, BanditReference, Environment, Flag, FormatEnum, PrecomputedFlagsPayload } from './interfaces';
import { Attributes } from './types';
export interface IQueryParams {
    apiKey: string;
    sdkVersion: string;
    sdkName: string;
}
export interface IQueryParamsWithSubject extends IQueryParams {
    subjectKey: string;
    subjectAttributes: Attributes;
}
export declare class HttpRequestError extends Error {
    message: string;
    status: number;
    cause?: Error | undefined;
    constructor(message: string, status: number, cause?: Error | undefined);
}
export interface IUniversalFlagConfigResponse {
    createdAt: string;
    format: FormatEnum;
    environment: Environment;
    flags: Record<string, Flag>;
    banditReferences: Record<string, BanditReference>;
}
export interface IBanditParametersResponse {
    bandits: Record<string, BanditParameters>;
}
export interface IHttpClient {
    getUniversalFlagConfiguration(): Promise<IUniversalFlagConfigResponse | undefined>;
    getBanditParameters(): Promise<IBanditParametersResponse | undefined>;
    getPrecomputedFlags(payload: PrecomputedFlagsPayload): Promise<IObfuscatedPrecomputedConfigurationResponse | undefined>;
    rawGet<T>(url: string): Promise<T | undefined>;
    rawPost<T, P>(url: string, payload: P): Promise<T | undefined>;
}
export default class FetchHttpClient implements IHttpClient {
    private readonly apiEndpoints;
    private readonly timeout;
    constructor(apiEndpoints: ApiEndpoints, timeout: number);
    getUniversalFlagConfiguration(): Promise<IUniversalFlagConfigResponse | undefined>;
    getBanditParameters(): Promise<IBanditParametersResponse | undefined>;
    getPrecomputedFlags(payload: PrecomputedFlagsPayload): Promise<IObfuscatedPrecomputedConfigurationResponse | undefined>;
    rawGet<T>(url: string): Promise<T | undefined>;
    rawPost<T, P>(url: string, payload: P): Promise<T | undefined>;
}
//# sourceMappingURL=http-client.d.ts.map