import { IConfigurationStore } from './configuration-store/configuration-store';
import { Entry } from './configuration-store/configuration-store-utils';
import { BanditParameters, BanditVariation, ConfigDetails, Environment, Flag, ObfuscatedFlag } from './interfaces';
import { BanditKey, FlagKey, HashedFlagKey } from './types';
export interface IConfiguration {
    getFlag(key: FlagKey | HashedFlagKey): Flag | ObfuscatedFlag | null;
    getFlags(): Record<FlagKey | HashedFlagKey, Flag | ObfuscatedFlag>;
    getBandits(): Record<BanditKey, BanditParameters>;
    getBanditVariations(): Record<FlagKey | HashedFlagKey, BanditVariation[]>;
    getFlagBanditVariations(flagKey: FlagKey | HashedFlagKey): BanditVariation[];
    getFlagVariationBandit(flagKey: FlagKey | HashedFlagKey, variationValue: string): BanditParameters | null;
    getBandit(key: BanditKey): BanditParameters | null;
    getFlagConfigDetails(): ConfigDetails;
    getFlagKeys(): FlagKey[] | HashedFlagKey[];
    isObfuscated(): boolean;
    isInitialized(): boolean;
}
export type ConfigStoreHydrationPacket<T extends Entry> = {
    entries: Record<string, T>;
    environment: Environment;
    createdAt: string;
    format: string;
    salt?: string;
};
export declare class StoreBackedConfiguration implements IConfiguration {
    private readonly flagConfigurationStore;
    private readonly banditVariationConfigurationStore?;
    private readonly banditModelConfigurationStore?;
    constructor(flagConfigurationStore: IConfigurationStore<Flag | ObfuscatedFlag>, banditVariationConfigurationStore?: (IConfigurationStore<BanditVariation[]> | null) | undefined, banditModelConfigurationStore?: (IConfigurationStore<BanditParameters> | null) | undefined);
    hydrateConfigurationStores(flagConfig: ConfigStoreHydrationPacket<Flag>, banditVariationConfig?: ConfigStoreHydrationPacket<BanditVariation[]>, banditModelConfig?: ConfigStoreHydrationPacket<BanditParameters>): Promise<boolean>;
    getBandit(key: string): BanditParameters | null;
    getFlagVariationBandit(flagKey: string, variationValue: string): BanditParameters | null;
    getFlag(key: string): Flag | ObfuscatedFlag | null;
    getFlagConfigDetails(): ConfigDetails;
    getFlagBanditVariations(flagKey: string): BanditVariation[];
    getFlagKeys(): string[];
    getFlags(): Record<string, Flag | ObfuscatedFlag>;
    isObfuscated(): boolean;
    isInitialized(): boolean;
    getBandits(): Record<string, BanditParameters>;
    getBanditVariations(): Record<string, BanditVariation[]>;
}
//# sourceMappingURL=i-configuration.d.ts.map