"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const js_base64_1 = require("js-base64");
/**
 * Decodes SDK tokens with embedded encoded data.
 */
class SdkTokenDecoder {
    constructor(sdkKey) {
        this.sdkKey = sdkKey;
        try {
            const [, payload] = sdkKey.split('.');
            const encodedPayload = payload ?? null;
            this.decodedParams = encodedPayload
                ? new URLSearchParams(js_base64_1.Base64.decode(encodedPayload))
                : null;
        }
        catch {
            this.decodedParams = null;
        }
    }
    getDecodedValue(key) {
        return this.decodedParams?.get(key) || null;
    }
    getEventIngestionHostname() {
        return this.getDecodedValue('eh');
    }
    getSubdomain() {
        return this.getDecodedValue('cs');
    }
    /**
     * Gets the raw SDK Key.
     */
    getToken() {
        return this.sdkKey;
    }
    /**
     * Checks if the SDK Key had the subdomain or event hostname encoded.
     */
    isValid() {
        if (!this.decodedParams)
            return false;
        return !!this.getEventIngestionHostname() || !!this.getSubdomain();
    }
}
exports.default = SdkTokenDecoder;
//# sourceMappingURL=sdk-token-decoder.js.map